Documentation
¶
Overview ¶
Package grpcrun @Author: Ciusyan 2023/2/26
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GoGrpc ¶
type GoGrpc struct {
Timeout time.Duration
Task map[string]*GrpcTask
// contains filtered or unexported fields
}
GoGrpc is used to run some goroutine of grpc. the grpc's return will filled in response and error Example:
func example() {
run := GoGrpc{}
run.AddNewTask(nil, nil, nil)
run.Call()
run.Wait()
}
func (*GoGrpc) AddNewTask ¶
func (*GoGrpc) SetTimeout ¶
SetTimeout reset timeout, replace default timeout with a special time duration
Click to show internal directories.
Click to hide internal directories.